Rendering diagrams
==================

.. currentmodule:: syntax_diagrams

We support rendering SVG and ASCII diagrams:

.. autofunction:: render_svg

.. autofunction:: render_text


Settings
--------

.. autoclass:: SvgRenderSettings(**kwargs)
    :members:

.. autoclass:: TextRenderSettings(**kwargs)
    :members:

.. autoclass:: EndClass
    :members:

.. autoclass:: ArrowStyle
    :members:


Errors
------

.. autoclass:: LoadingError
    :members:
